@@ -1,5 +1,4 @@
-from typing import (FrozenSet,
-                    Iterable,
+from typing import (Iterable,
                     List,
                     Optional)
 
@@ -155,10 +154,6 @@ class QuadEdge:
         opposite._start = opposite_side.end
 
 
-def edge_to_endpoints(edge: QuadEdge) -> FrozenSet[Point]:
-    return frozenset((edge.start, edge.end))
-
-
 def edge_to_neighbours(edge: QuadEdge) -> List[QuadEdge]:
     return (list(_edge_to_incidents(edge))
             + list(_edge_to_incidents(edge.opposite)))
