@@ -1,9 +1,9 @@
-from ground.base import Orientation
+from ground.base import (Location,
+                         Orientation)
 from ground.hints import Point
 from reprit.base import generate_repr
 
 from .edge import Edge
-from .location import Location
 from .node import Node
 from .trapezoid import Trapezoid
 
