@@ -1,7 +1,5 @@
 from .core.trapezoidal.graph import Graph
 from .core.trapezoidal.hints import Shuffler
-from .core.trapezoidal.location import Location
 
 Graph = Graph
-Location = Location
 Shuffler = Shuffler
